.. _rtdl:

rtdl
====

.. currentmodule:: rtdl

.. automodule:: rtdl
    :no-members:

Activations
-----------

.. autosummary::
    :nosignatures:
    :toctree: api
    :template: class.rst

    ReGLU
    GEGLU

Tokens and Embeddings
---------------------

.. autosummary::
    :nosignatures:
    :toctree: api
    :template: class.rst

    NumericalFeatureTokenizer
    CategoricalFeatureTokenizer
    FeatureTokenizer
    CLSToken

Attention
---------

.. autosummary::
    :nosignatures:
    :toctree: api
    :template: class.rst

    MultiheadAttention

Models
------

.. autosummary::
    :nosignatures:
    :toctree: api
    :template: class.rst

    MLP
    ResNet
    Transformer
    FTTransformer

Functions
---------

.. autofunction:: reglu

.. autofunction:: geglu
